@@ -1,6 +1,7 @@
-#  Copyright (c) 1997-2018
-#  Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-#  http://www.polymake.org
+#  Copyright (c) 1997-2021
+#  Ewgenij Gawrilow, Michael Joswig, and the polymake team
+#  Technische Universität Berlin, Germany
+#  https://polymake.org
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License as published by the
@@ -21,20 +22,20 @@ package Polymake::Core::Property;
 
 #  Constructor
 #
-#  new Property('Name', $type, ObjectType, options);
+#  new Property('name', $type, BigObjectType, options);
 
 use Polymake::Struct (
    [ 'new' => '$$$%' ],
    [ '$name | property_name' => '#1' ],   # 'property name'
-   [ '$defined_for' => '#3' ],    # ObjectType where the property definition appeared, common for all clones and aliases
-   [ '$belongs_to' => '#3' ],     # ObjectType owning this instance
+   [ '$defined_for' => '#3' ],    # BigObjectType where the property definition appeared, common for all clones and aliases
+   [ '$belongs_to' => '#3' ],     # BigObjectType owning this instance
    [ '$application' => 'undef' ], # Application where it's defined (if != defined_for->application)
-   [ '$extension' => '$Application::extension' ],
-   [ '$type' => '#2' ],           # PropertyType | ObjectType
+   [ '$extension' => '$Extension::loading' ],
+   [ '$type' => '#2' ],           # PropertyType | BigObjectType
    [ '$flags' => '#%', default => '0' ],
 
                                   # the following fields contain \&sub or "method name",
-                                  #   methods are called via the Object
+                                  #   methods are called via the BigObject
    [ '$canonical' => '#%', default => 'undef' ],
    [ '$equal' => '#%', default => 'undef' ],
 
@@ -46,7 +47,7 @@ use Polymake::Struct (
 
                                     # for aliases defined in derived objects:
    [ '$overrides' => 'undef' ],     # "PropName" original property overridden by this one
-   [ '$overrides_for' => 'undef' ], # ObjectType where the overriding alias is defined
+   [ '$overrides_for' => 'undef' ], # BigObjectType where the overriding alias is defined
 
    '%key | property_key',         # The address of the hash itself serves as a search key in the objects' dictionaries,
                                   # production rule lists, permutation sensitivity lists, etc. - all kinds of lists where
@@ -78,10 +79,10 @@ use Polymake::Enum Flags => {
 
 sub new {
    my $self=&_new;
-   if (instanceof ObjectType($self->type)) {
+   if (instanceof BigObjectType($self->type)) {
       $self->flags |= Flags::is_subobject;
    }
-   if ($Application::plausibility_checks) {
+   if ($enable_plausibility_checks) {
       if ($self->flags & Flags::is_subobject) {
          if ($self->flags & Flags::is_non_storable) {
             croak( "only atomic properties can be declared non-storable" );
@@ -124,16 +125,16 @@ sub new {
 }
 ####################################################################################
 sub clone {
-   my ($src)=@_;
-   my $self=inherit_class([ @$src ], $src);
+   my ($src) = @_;
+   my $self = inherit_class([ @$src ], $src);
    if ($src->new_instance_deputy) {
-      $self->new_instance_deputy=new NewMultiInstance($self, $src->new_instance_deputy->key);
+      $self->new_instance_deputy = new NewMultiInstance($self, $src->new_instance_deputy->key);
    }
    $self
 }
 ####################################################################################
 sub override_by {
-   my ($src, $name, $owner, $new_type)=@_;
+   my ($src, $name, $owner, $new_type) = @_;
    my $self = &clone;
    $self->name = $name;
    $self->belongs_to = $owner;
@@ -141,7 +142,7 @@ sub override_by {
       $self->overrides_for = $owner;
       $self->overrides = $src->name;
    }
-   if (defined $new_type) {
+   if (defined($new_type)) {
       $self->type = $new_type;
       if ($new_type->abstract) {
          $self->flags &= ~Flags::is_concrete;
@@ -155,20 +156,20 @@ sub override_by {
 ####################################################################################
 # find the property instance suitable for the given object type,
 # taking into account overrides and augmentations
-# Property, ObjectType, downcast_flag => Property
+# Property, BigObjectType, downcast_flag => Property
 sub instance_for_owner {
-   my ($self, $proto, $down)=@_;
-   if ($self->belongs_to==$proto) {
+   my ($self, $proto, $down) = @_;
+   if ($self->belongs_to == $proto) {
       $self
    } elsif ($down) {
       $proto->property($self->name)
    } elsif ($proto->isa($self->defined_for)) {
       until ($proto->isa($self->belongs_to)) {
-         $self= $proto->lookup_property($self->name) //
-                (defined($self->overrides) &&
-                 $self->belongs_to->lookup_overridden_property($self)
-                   or croak( "internal error: can't find an instance of property ", $self->name,
-                             " for object type ", $proto->full_name ));
+         $self = $proto->lookup_property($self->name) //
+                 (defined($self->overrides) &&
+                  $self->belongs_to->lookup_overridden_property($self)
+                    or croak( "internal error: can't find an instance of property ", $self->name,
+                              " for object type ", $proto->full_name ));
       }
       $self
    } else {
@@ -177,7 +178,7 @@ sub instance_for_owner {
 }
 ####################################################################################
 sub analyze {
-   my ($self, $pkg)=@_;
+   my ($self, $pkg) = @_;
    if ($self->flags & Flags::is_subobject) {
       if ($self->flags & Flags::is_twin) {
          croak( "a twin property cannot be augmented" );
@@ -195,13 +196,15 @@ sub analyze {
 }
 ####################################################################################
 sub change_to_augmented {
-   my ($self, $augm)=@_;
+   my ($self, $augm) = @_;
    $self->type = $augm;
    if ($self->belongs_to->abstract) {
       $self->flags &= ~Flags::is_concrete;
-      choose_methods($self);
+   } else {
+      $self->flags |= Flags::is_concrete;
    }
    $self->flags |= Flags::is_augmented;
+   choose_methods($self);
    if ($self->new_instance_deputy) {
       $self->new_instance_deputy->update_flags;
    }
@@ -209,9 +212,9 @@ sub change_to_augmented {
 }
 ####################################################################################
 sub clone_for_augmented {
-   my ($src, $augm, $proto)=@_;
-   my $self=&clone;
-   $self->belongs_to=$proto;
+   my ($src, $augm, $proto) = @_;
+   my $self = &clone;
+   $self->belongs_to = $proto;
    change_to_augmented($self, $augm);
    $self
 }
@@ -243,7 +246,7 @@ sub clone_for_owner {
 }
 ####################################################################################
 sub choose_methods {
-   my ($self)=@_;
+   my ($self) = @_;
    if ($self->flags & Flags::is_concrete) {
       if ($self->flags & Flags::is_subobject) {
          $self->accept = \&accept_subobject;
@@ -288,7 +291,7 @@ sub accept_subobject : method {
    }
 
    unless ($trusted) {
-      is_object($value) or croak( "property ", $self->name, " needs an Object\n" );
+      is_object($value) or croak( "property ", $self->name, " needs a BigObject\n" );
       unless (UNIVERSAL::isa($value, $subobj_type->pure_type->pkg)) {
          # if the source object can't be converted to our type, it will croak():
          $value=$subobj_type->pure_type->construct->($value);
@@ -299,7 +302,7 @@ sub accept_subobject : method {
       $value=$value->copy($parent_obj, $self);
    } else {
       $value->property=$self;
-      guarded_weak($value->parent=$parent_obj, $value, \&Object::forget_parent_property);
+      guarded_weak($value->parent=$parent_obj, $value, \&BigObject::forget_parent_property);
       if ($self->flags & Flags::is_augmented && (my $given_type=$value->type) != $subobj_type) {
          $value->perform_cast($subobj_type->final_type($given_type), 1);
       }
@@ -308,9 +311,9 @@ sub accept_subobject : method {
    $value->is_temporary= $temp || defined($parent_obj->parent) && $parent_obj->is_temporary;
 
    if (defined($value->transaction)) {
-      if ($value->has_cleanup) {
-         Transaction::merge_temporaries($value->transaction->temporaries, delete $Scope->cleanup->{$value});
-         $value->has_cleanup=0;
+      if ($value->cleanup_table) {
+         Transaction::merge_temporaries($value->transaction->temporaries, delete $value->cleanup_table->{$value});
+         $value->cleanup_table=0;
       }
       if (defined($parent_obj->transaction)) {
          $parent_obj->transaction->descend($value, 1) unless ($temp && defined($parent_obj->transaction->rule));
@@ -320,11 +323,11 @@ sub accept_subobject : method {
    } elsif (defined($parent_obj->transaction)) {
       unless ($temp && defined($parent_obj->transaction->rule)) {
          ## FIXME: suspicious logical expression
-         if (not($self->flags & Flags::is_subobject_array) || $value->has_cleanup) {
+         if (not($self->flags & Flags::is_subobject_array) || $value->cleanup_table) {
             $parent_obj->transaction->descend($value, !($self->flags & Flags::is_permutation));
-            if ($value->has_cleanup) {
-               $value->transaction->temporaries = delete $Scope->cleanup->{$value};
-               $value->has_cleanup = 0;
+            if ($value->cleanup_table) {
+               $value->transaction->temporaries = delete $value->cleanup_table->{$value};
+               $value->cleanup_table = 0;
             }
          }
       }
@@ -336,10 +339,10 @@ sub accept_subobject : method {
    $value
 }
 
-# parent Object, temporary flag => empty Object
+# parent BigObject, temporary flag => empty Object
 sub create_subobject : method {
    my $self=instance_for_owner($_[0], $_[1]->type, 1);
-   accept_subobject($self, Object::new($self->subobject_type->pkg), $_[1], 1, $_[2]);
+   accept_subobject($self, BigObject::new($self->subobject_type->pkg), $_[1], 1, $_[2]);
 }
 
 sub subobject_type {
@@ -438,8 +441,8 @@ sub copy_builtin : method {
 }
 ####################################################################################
 sub qualified_name {
-   my ($self)=@_;
-   defined($self->application) ? $self->application->name . "::" . $self->name : $self->name
+   my ($self) = @_;
+   $self->defined_for->qualified_name . "." . $self->name
 }
 
 *required_extensions = \&PropertyType::required_extensions;
